cgdat.qt_custom — CGDAT 2.0.8 documentation

# cgdat.qt_custom

This package contains all the additional classes and functions that are used in the CGDAT data anaylsis tool. It contains the following components:

Modules:

`cgdat.qt_custom.qt_dialogs` | This file contains some dialog classes that are created for the CGDAT GUI.
`cgdat.qt_custom.qt_extra` | This module contains classes and functions that add added custom made widgets and functionalities to the qt GUI.
`cgdat.qt_custom.qt_thread` | This module contains the classes and functions that are used qt gui to enable multithreading.